#
# spec file for package gnome-pie
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-pie
Version:        0.7.3
Release:        1.6
Summary:        A circular application launcher for GNOME
License:        MIT
Group:          System/GUI/GNOME
URL:            https://simmesimme.github.io/gnome-pie.html
Source:         https://github.com/Simmesimme/Gnome-Pie/archive/v%{version}.tar.gz#/Gnome-Pie-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  vala >= 0.22
BuildRequires:  pkgconfig(appindicator3-0.1)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libbamf3)
BuildRequires:  pkgconfig(libgnome-menu-3.0)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xtst)

%description
GNOME-Pie is a circular application launcher (pie menu).
It is made of several pies, each consisting of multiple slices.
The user presses a key stroke which opens the desired pie. By
activating one of its slices, applications may be launched, key
presses may be simulated or files can be opened.

%prep
%setup -q -n Gnome-Pie-%{version}

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install
%suse_update_desktop_file %{name} -r Utilities DesktopUtility
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc AUTHORS TRANSLATING
%{_bindir}/gnome-pie
%{_datadir}/applications/gnome-pie.desktop
%{_datadir}/doc/gnome-pie/
%dir %{_datadir}/gnome-pie/
%dir %{_datadir}/gnome-pie/themes/
%{_datadir}/gnome-pie/themes/adwaita/
%{_datadir}/gnome-pie/themes/adwaita_big/
%{_datadir}/gnome-pie/themes/bright/
%{_datadir}/gnome-pie/themes/elementary/
%{_datadir}/gnome-pie/themes/funky/
%{_datadir}/gnome-pie/themes/gloss/
%{_datadir}/gnome-pie/themes/minimalistic_text/
%{_datadir}/gnome-pie/themes/numix/
%{_datadir}/gnome-pie/themes/o-pie/
%{_datadir}/gnome-pie/themes/simple/
%{_datadir}/gnome-pie/themes/simple_clock/
%{_datadir}/gnome-pie/themes/slim/
%{_datadir}/gnome-pie/themes/space_clock/
%{_datadir}/gnome-pie/themes/unity/
%{_datadir}/gnome-pie/ui/
%{_datadir}/gnome-pie/ui/shapes/
%{_datadir}/icons/hicolor/scalable/apps/gnome-pie-symbolic.svg
%{_datadir}/icons/hicolor/scalable/apps/gnome-pie.svg
%{_datadir}/locale/zanata.xml
%{_mandir}/man1/gnome-pie.1%{?ext_man}

%changelog
* Tue May 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.7.3:
  + This does not contain any new feature but makes Gnome-Pie
    compatible with more recent versions of the Vala compiler and
    implements some minor fixes.
- Drop gnome-pie-fix-build-vala046.patch: fixed upstream.
* Tue Nov 26 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.2
  * New Feature: Pies will not close when CTRL or SHIFT is
    pressed while clicking. This feature got requested several
    times so it is now reality! You can now perform multiple
    actions without having to re-open the pie.
  * Improvement: Gnome-Pie switched from GPL to MIT license.
  * Improvement: Gnome-Pie will now hide when it looses focus.
    This is helpful under wayland when users click on panels for
    example.
  * Improvement: Fixed several deprecation warnings.
  * Improvement: Added Dutch translation (thank you, Heimen
    Stoffels).
  * Bugfix: Fixed a segmentation fault when a new pie was added
    under Wayland.
  * Bugfix: Fixed some typos in the English translation (thank
    you, Jörg Frings-Fürst).
  * Bugfix: Removed creation of obsolete statistics file.
  * Bugfix: Fixed build with vala 0.42 (thank you, Rico
    Tzschichholz).
- Dropped gnome-pie-fix-build-vala042.patch (merged upstream)
- Added gnome-pie-fix-build-vala046.patch (fix build with vala
  0.46+)
- Spec cleanup
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 0.7.1:
  + Use gdk monitor on wayland if possible.
- Add gnome-pie-fix-build-vala042.patch: Fix build with vala 0.42.
  Only apply when vala 0.42.x and newer is present during build.
- Drop gnome-pie-fix-invalid-chainup.patch: Fixed upstream.
- Run spec-cleaner, modernize spec.
- Conditionalize post(un) handling of desktop_database_post(un) and
  icon_theme_cache_post(un), no longer needed for modern versions
  of openSUSE.
* Sun Aug 20 2017 zaitor@opensuse.org
- Drop pkgconfig(unique-3.0) BuildRequires: No longer needed.
* Tue Aug  8 2017 jengelh@inai.de
- Fix RPM group. Drop redundant mention of Linux.
* Fri Feb 24 2017 zaitor@opensuse.org
- Update to version 0.7.0:
  + New Feature: Added the possibility to automatically fill the
    fields “name”, “command” and “icon” of a new slice by selecting
    an application from a list.
  + Improvement: The library “bamf” which has been made optional
    before is now completely removed from the dependencies. This
    makes the code base easier to manage and it seems that there is
    no improvement to the icon selection when using this library.
  + Bugfix:
  - It is now possible again to drag’n’drop URLs and URIs to the
    pie preview.
  - Long press for activation of slices works again.
- Add gnome-pie-fix-invalid-chainup.patch: Fix invalid chainup
  discovered by valac 0.35.x
* Fri Sep  2 2016 zaitor@opensuse.org
- Update to version 0.6.9:
  + Assign icon name to preferences window.
* Sun Feb 28 2016 mailaender@opensuse.org
- initial packaging
